## Arches for Science 2.0.2 Release Notes


### Bug Fixes and Enhancements

- Allows user to scroll side panel in sample taking step [#1605](https://github.com/archesproject/arches-for-science/pull/1605)
- Prevents signal receiver from attempting to delete tiles that do not exist (causing error) [#1605](https://github.com/archesproject/arches-for-science/pull/1605)
- Prevents user from attempting to save an analysis area without an annotation geometry [#1605](https://github.com/archesproject/arches-for-science/pull/1605)
- Removes asterisks from analysis and sample taking steps because there is already a 'required' label and the asterisk was obscuring the label [#1605](https://github.com/archesproject/arches-for-science/pull/1605)

### Dependency changes:

```
Python:
    Upgraded:
        arches 7.6.4 -> 7.6.6
JavaScript:
    Upgraded:
        arches 7.6.3 -> 7.6.6
```

### Breaking Changes
Due to changes in how projects and apps are configured in the final release of Arches 7.6, there are significant project alterations necessary to migrate from Arches for Science 1.1 to Arches for Science 2.0.

### Upgrading Arches for Science 
1. Start by upgrading your project to run using [Arches 7.6](https://github.com/archesproject/arches/blob/dev/7.6.x/releases/7.6.0.md#upgrading-arches). 

2. Update arches-for-science in your project's package.json file:
    ```
    "arches_for_science": "archesproject/arches-for-science#dev/2.0.x"
    ```

3. Add arches_for_science to your project's dependencies in your pyproject.toml file:
    ```
    "arches_for_science>=2.0.2,<2.1.0"
    ```

4. Upgrade to Arches for Science 2.0.2
    ```
    pip install --upgrade arches_for_science==2.0.2
    ```


